<?xml version="1.0" encoding="ISO-8859-1"?>
<!--
<mapping>
  <template name="/home/dmae/manager/etc/templates-ev/Admin_Compare_Two_Cartridges.xsl"
    label="Admin Compare files in two Cartridges" user="dmae">
    <templateinfo>Compare files stored in two cartrides. (Optionally, format one cartridge when contents are identical).</templateinfo>
    <dir name="*"/>
    <subsystem name="*"/>
    <filetype name="*" format="*" />
  </template>
  <param>
    <group label="Job parameters">
      <input name="TITLE" type="text" size="50" label="Job title" value="">
        Optional: Title for the job.
      </input>
      <select name="PRIORITY" label="Priority"  type="text" size="1">
        Select the priority at which the job should be executed.
        <option label="LOW"      value="LOW"></option>
        <option label="MEDIUM"   value="MEDIUM"></option>
        <option label="HIGH"     value="HIGH"></option>
        <option label="CRITICAL" value="CRITICAL"></option>
      </select>
      <select name="hold" type="text" label="Defer job execution">
        Select if the job should be executed at a later time.
        <option value="no" label="no" />
        <option value="yes" label="yes" />
      </select>
      <input name="STARTTIME" type="text" size="50" label="Start Time (YYYY-MM-DD HH:MM:SS)" value="">
        The start time for the job.  The default is now if not deferred and the night window if deferred.
      </input>
    </group>
    
    <group label="Tape parameters">
      <input name="SRC_TAPE" type="text" size="50" label="Name of Tape Cartridge 1" value="">
        Name / Barcode of tape to read the files on it
      </input>
      <input name="TRG_TAPE" type="text" size="50" label="Name of Tape Cartridge 2 (to be formatted after comparison)" value="">
        Name / Barcode of tape to write the files
      </input>
      <select name="format" type="text" label="Format Cartridge 2">
        Select if format operation is to be executed after comparison
        <option value="no" label="no" />
        <option value="yes" label="yes" />
      </select>
      <select name="TAPE_TYPE" type="text" label="Type of Tape to format">
        Select the type of the tape to be imported.
        <option value="LTO5"   label="LTO5" />
        <option value="LTO6"   label="LTO6" />
        <option value="TS1140" label="TS1140" />
      </select>
      <input name="ADD_TO_POOL" type="text" size="20" label="Name of Pool to add tape">
        The name of the pool to which the tape is to be added.
      </input>
      <input name="ORGUNIT_IN" type="text" size="10" label="Organization unit" value="">
        Optional: The Organization Unit for this tape.
      </input>
    </group>
  </param>
</mapping>
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
                xmlns:gs="global_settings.xsl">
  <xsl:import href="global_settings.xsl"/>
  <xsl:output method="xml" indent="yes"/>
  <xsl:template match="properties">
    
    <xsl:param name="TITLE" select="translate(param[@name='TITLE'],$TRANSLATE_SRC,$TRANSLATE_DST)" />
    <xsl:param name="PRIORITY" select="param[@name='PRIORITY']" />
    <xsl:param name="format" select="param[@name='format']" />
    <xsl:param name="STARTTIME" select="param[@name='STARTTIME']" />
    <xsl:param name="SOURCE_TAPE" select="param[@name='SRC_TAPE']" />
    <xsl:param name="TARGET_TAPE" select="param[@name='TRG_TAPE']" />
    <xsl:param name="TAPE_TYPE" select="param[@name='TAPE_TYPE']" />
    <xsl:param name="ADD_TO_POOL_IN" select="param[@name='ADD_TO_POOL']" />
    <xsl:param name="ORGUNIT_IN" select="param[@name='ORGUNIT_IN']" />
    <xsl:variable name="ORGUNIT">
      <xsl:value-of select="gs:getValue($ORGUNIT_IN,$DEFAULT_ORGUNIT)"/>
    </xsl:variable>

    <xsl:variable name="EXEC_NAME">
      <xsl:text>/home/dmae/manager/opt/extcmd/extcmd_files_in_tape.py</xsl:text>
    </xsl:variable>

    <job id="admin_compare_2_carts">
      <param name="priority"><xsl:value-of select="gs:getPriorityValue($PRIORITY)"/></param>
      <param name="job_type">compare_two_carts</param>
      <xsl:variable name="TITLE_DEFAULT">Admin Compare two cartridges &#x005B;<xsl:value-of select="$SOURCE_TAPE"/>&#x005D; and &#x005B;<xsl:value-of select="$TARGET_TAPE"/>&#x005D;</xsl:variable>
      <param name="title"><xsl:value-of select="gs:getValue($TITLE,$TITLE_DEFAULT)"/></param>

    <step id="compare" agent="external_command">
      <param name="title">Compare contents of two tape cartridges</param>
      <param name="exec_name"><xsl:value-of select="$EXEC_NAME"/></param>
      <param name="source_filename_list"></param>
      <param name="target_filename_list"></param>
      <param name="additional_parameters"><xsl:value-of select="$SOURCE_TAPE"/><xsl:text> </xsl:text><xsl:value-of select="$TARGET_TAPE"/></param>
      <param name="fail_on_error">yes</param>
      <param name="chmod_file"></param>
      <param name="stop_deliver_on_failure">yes</param>
      <param name="org_unit"><xsl:value-of select="$ORGUNIT"/></param>
    </step>      

    <xsl:if test="$format='yes'">

      <xsl:variable name="ADD_TO_POOL">
        <xsl:value-of select="gs:getValue($ADD_TO_POOL_IN,$DEFAULT_POOL)"/>
      </xsl:variable>

      <step id="format" agent="ltfs_tape_admin">
        <param name="title">Format tape [<xsl:value-of select="$TARGET_TAPE"/>]</param>
        <param name="subfunction">format</param>
        <param name="target_tape"><xsl:value-of select="$TARGET_TAPE"/></param>
<!--        
        <param name="tape_type"><xsl:value-of select="$TAPE_TYPE"/></param>
-->        
        <param name="add_to_pool"><xsl:value-of select="$ADD_TO_POOL"/></param>
        <param name="org_unit"><xsl:value-of select="$ORGUNIT"/></param>
        <param name="options">-f</param>
        <param name="predlist">
          <value>compare</value>
        </param>
      </step>
    </xsl:if>
    </job>
  </xsl:template>
</xsl:stylesheet>
