<?xml version="1.0" encoding="ISO-8859-1"?>
<!--
<mapping>
  <template name="/home/dmae/manager/etc/templates-ev/Admin_Copy_All_Files.xsl"
    label="Admin Copy all files" user="dmae">
    <templateinfo>Copy All files in a source cartridge to a target cartridge.</templateinfo>
    <dir name="*"/>
    <subsystem name="*"/>
    <filetype name="*" format="*" />
  </template>
  <param>
    <group label="Job parameters">
      <input name="TITLE" type="text" size="50" label="Job title" value="">
        Optional: Title for the job.
      </input>
      <select name="PRIORITY" label="Priority"  type="text" size="1">
        Select the priority at which the job should be executed.
        <option label="LOW"      value="LOW"></option>
        <option label="MEDIUM"   value="MEDIUM"></option>
        <option label="HIGH"     value="HIGH"></option>
        <option label="CRITICAL" value="CRITICAL"></option>
      </select>
      <select name="hold" type="text" label="Defer job execution">
        Select if the job should be executed at a later time.
        <option value="no" label="no" />
        <option value="yes" label="yes" />
      </select>
      <input name="STARTTIME" type="text" size="50" label="Start Time (YYYY-MM-DD HH:MM:SS)" value="">
        The start time for the job.  The default is now if not deferred and the night window if deferred.
      </input>
    </group>
    
    <group label="Tape parameters">
      <input name="SRC_TAPE" type="text" size="50" label="Name of Source Tape" value="">
        Name / Barcode of tape to read the files on it
      </input>
      <input name="TRG_TAPE" type="text" size="50" label="Name of Target Tape" value="">
        Name / Barcode of tape to write the files
      </input>
      <input name="ORGUNIT_IN" type="text" size="10" label="Organization unit" value="">
        Optional: The Organization Unit for this tape.
      </input>
    </group>
  </param>
</mapping>
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
                xmlns:gs="global_settings.xsl">
  <xsl:import href="global_settings.xsl"/>
  <xsl:output method="xml" indent="yes"/>
  <xsl:template match="properties">
    
    <xsl:param name="TITLE" select="translate(param[@name='TITLE'],$TRANSLATE_SRC,$TRANSLATE_DST)" />
    <xsl:param name="PRIORITY" select="param[@name='PRIORITY']" />
    <xsl:param name="hold" select="param[@name='hold']" />
    <xsl:param name="STARTTIME" select="param[@name='STARTTIME']" />
    <xsl:param name="SOURCE_TAPE" select="param[@name='SRC_TAPE']" />
    <xsl:param name="TARGET_TAPE" select="param[@name='TRG_TAPE']" />
    <xsl:param name="ORGUNIT_IN" select="param[@name='ORGUNIT_IN']" />
    <xsl:variable name="ORGUNIT">
      <xsl:value-of select="gs:getValue($ORGUNIT_IN,$DEFAULT_ORGUNIT)"/>
    </xsl:variable>

    <xsl:variable name="job_template_sub_job">/home/dmae/manager/etc/templates-ev/Admin_Copy_All_Files_Subjob.xsl</xsl:variable>
    <xsl:variable name="primary_ecsi_url">http://localhost:9090/ecsi/services/admirafunctions</xsl:variable>
    <xsl:variable name="secondary_ecsi_url">http://localhost:9090/ecsi/services/admirafunctions</xsl:variable>
    <xsl:variable name="remote_userid">dmae</xsl:variable>

<!-- replace passwoed for your dmae's encrypted password -->
    <xsl:variable name="remote_password">80f379e872611dfc72c7ea8ed3c929389ef7</xsl:variable>

    <xsl:variable name="remote_database">admira</xsl:variable>

    <xsl:variable name="notify_style_tapedir">/home/dmae/manager/etc/Admin_Notify_Copy_All_Files_TapeDir_Destination.xml</xsl:variable>
    <xsl:variable name="notify_style_subjob">/home/dmae/manager/etc/Admin_Notify_Copy_All_Files_Subjob_Destination.xml</xsl:variable>

    <xsl:variable name="xml_filename_tapedir">
      <xsl:text>temp/</xsl:text>
      <xsl:value-of select="$SOURCE_TAPE"/>
      <xsl:text>_notify_tapedir.xml</xsl:text>
    </xsl:variable>
    <xsl:variable name="xml_filename_subjob">
      <xsl:text>temp/</xsl:text>
      <xsl:value-of select="$SOURCE_TAPE" />
      <xsl:text>_notify_subjob.xml</xsl:text>
    </xsl:variable>

    <xsl:variable name="xml_export_filename">
      <xsl:text>/home/dmae/manager/cache/tape_directory/</xsl:text>
      <xsl:value-of select="$SOURCE_TAPE"/>
      <xsl:text>.xml</xsl:text>
    </xsl:variable>


    <job id="addon_copy_all_files">
      <param name="priority"><xsl:value-of select="gs:getPriorityValue($PRIORITY)"/></param>
      <param name="job_type">copy_all_files</param>
      <xsl:variable name="TITLE_DEFAULT">Addon: Copy all files of tape &#x005B;<xsl:value-of select="$SOURCE_TAPE"/>&#x005D; to tape &#x005B;<xsl:value-of select="$TARGET_TAPE"/>&#x005D;</xsl:variable>
      <param name="title"><xsl:value-of select="gs:getValue($TITLE,$TITLE_DEFAULT)"/></param>

    <step id="create_xml_tapedir" agent="notify">
      <param name="title">Create XML with tape contents</param>
      <param name="dest_filename"><xsl:value-of select="$notify_style_tapedir"/></param>
      <param name="target_filename"><xsl:value-of select="$xml_filename_tapedir"/></param>
      <properties id="parameters">
        <param name="xml_filename"><xsl:value-of select="$xml_filename_tapedir"/></param>
        <param name="target_tape"><xsl:value-of select="$SOURCE_TAPE"/></param>
        <param name="xml_export_filename"><xsl:value-of select="$xml_export_filename"/></param>
      </properties>
      <param name="fail_on_predecessor_error">yes</param>
      <param name="fail_on_error">yes</param>
      <param name="stop_deliver_on_failure">yes</param>
      <param name="org_unit"><xsl:value-of select="$ORGUNIT"/></param>
    </step>      

    <step id="create_subjob_parameter" agent="notify">
      <param name="title">Subjob parameter for copying all files</param>
      <param name="dest_filename"><xsl:value-of select="$notify_style_subjob"/></param>
      <param name="target_filename"><xsl:value-of select="$xml_filename_subjob"/></param>
      <param name="content_filename"><xsl:value-of select="$xml_export_filename"/></param>
      <properties id="parameters">
        <param name="xml_filename"><xsl:value-of select="$xml_filename_subjob"/></param>
        <param name="tape_id"><xsl:value-of select="$SOURCE_TAPE"/></param>
        <param name="target_tape"><xsl:value-of select="$TARGET_TAPE"/></param>
      </properties>
      <param name="fail_on_predecessor_error">yes</param>
      <param name="fail_on_error">yes</param>
      <param name="stop_deliver_on_failure">yes</param>
      <param name="hold_in_cache">no</param>
      <param name="org_unit"><xsl:value-of select="$ORGUNIT"/></param>
      <param name="predlist">
        <value>create_xml_tapedir</value>
      </param>
    </step>

    <step id="start_subjob" agent="ecsi_client">
      <param name="title">Create subjob for copying all files</param>
      <param name="subfunction">startTemplateJob</param>
      <param name="primary_ecsi_url"><xsl:value-of select="$primary_ecsi_url"/></param>
      <param name="secondary_ecsi_url"><xsl:value-of select="$secondary_ecsi_url"/></param>
      <param name="remote_userid"><xsl:value-of select="$remote_userid"/></param>
      <param name="remote_password"><xsl:value-of select="$remote_password"/></param>
      <param name="remote_database"><xsl:value-of select="$remote_database"/></param>
      <param name="template_filename">
      	<xsl:value-of select="$job_template_sub_job"/>
      </param>
      <param name="template_variables_filename">
        <xsl:text>/home/dmae/manager/cache/</xsl:text>
        <xsl:value-of select="$xml_filename_subjob" />
      </param>
      <param name="mode_synchronous">no</param>
      <param name="fail_on_predecessor_error">yes</param>
      <param name="fail_on_error">yes</param>
      <param name="org_unit"><xsl:value-of select="$ORGUNIT"/></param>
      <param name="predlist">
        <value>create_subjob_parameter</value>
      </param>
    </step>          

    </job>
  </xsl:template>
</xsl:stylesheet>
