<?xml version="1.0" encoding="ISO-8859-1"?>
<!--
<mapping>
  <template name="/home/dmae/manager/etc/templates-ev/Admin_Import_LTFS_Media.xsl"
            label="Admin Import LTFS Media" user="dmae">
    <templateinfo>Import LTFS tape to filesystem (verify tape format, import tape to the library, import the files to database).</templateinfo>
    <dir name="*"/>
    <subsystem name="*"/>
    <filetype name="*" format="*" />
  </template>
  <param>
    <group label="Job parameters">
      <input name="TITLE" type="text" size="50" label="Job title" value="">
        Optional: Title for the job.
      </input>
      <select name="PRIORITY" label="Priority"  type="text" size="1">
        Select the priority at which the job should be executed.
        <option label="LOW"      value="LOW"></option>
        <option label="MEDIUM"   value="MEDIUM"></option>
        <option label="HIGH"     value="HIGH"></option>
        <option label="CRITICAL" value="CRITICAL"></option>
      </select>
      <select name="hold" type="text" label="Defer job execution">
        Select if the job should be executed at a later time.
        <option value="no" label="no" />
        <option value="yes" label="yes" />
      </select>
      <input name="STARTTIME" type="text" size="50" label="Start Time (YYYY-MM-DD HH:MM:SS)" value="">
        The start time for the job.  The default is now if not deferred and the night window if deferred.
      </input>
    </group>
    <group label="Tape parameters">
      <input name="TARGET_TAPE" type="text" size="20" label="Name of Tape to import" value="">
        The barcode of the tape to be imported.
      </input>
      <select name="TAPE_TYPE" type="text" label="Type of Tape to import">
        Select the type of the tape to be imported.
        <option value="LTO5"  label="LTO5" />
        <option value="LTO6"   label="LTO6" />
        <option value="TS1140" label="TS1140" />
      </select>
      <input name="ADD_TO_POOL" type="text" size="20" label="Name of Pool to add tape to" value="">
        The name of the pool to which the tape is to be added.
      </input>
      <input name="ORGUNIT_IN" type="text" size="10" label="Organization unit" value="">
        Optional: The Organization Unit for this tape.
      </input>
    </group>
  </param>
</mapping>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
                 xmlns:gs="global_settings.xsl">
  <xsl:import href="global_settings.xsl"/>
  <xsl:output method="xml" indent="yes"/>
  <xsl:template match="properties">
    <xsl:param name="TITLE" select="translate(param[@name='TITLE'],$TRANSLATE_SRC,$TRANSLATE_DST)" />
    <xsl:param name="PRIORITY" select="param[@name='PRIORITY']" />
    <xsl:param name="hold" select="param[@name='hold']" />
    <xsl:param name="STARTTIME" select="param[@name='STARTTIME']" />
    <xsl:param name="TARGET_TAPE" select="param[@name='TARGET_TAPE']" />
    <xsl:param name="TAPE_TYPE" select="param[@name='TAPE_TYPE']" />
    <xsl:param name="ADD_TO_POOL_IN" select="param[@name='ADD_TO_POOL']" />
    <xsl:param name="ORGUNIT_IN" select="param[@name='ORGUNIT_IN']" />

    <xsl:variable name="ORGUNIT">
      <xsl:value-of select="gs:getValue($ORGUNIT_IN,$DEFAULT_ORGUNIT)"/>
    </xsl:variable>
    <xsl:variable name="ADD_TO_POOL">
      <xsl:value-of select="gs:getValue($ADD_TO_POOL_IN,$DEFAULT_POOL)"/>
    </xsl:variable>

    <job id="ltfs_tape_admin_verify-format_tape_job">
      <param name="priority"><xsl:value-of select="gs:getPriorityValue($PRIORITY)"/></param>
      <param name="job_type">admin</param>

      <xsl:variable name="TITLE_DEFAULT">LTFS Tape Admin: Verify format of tape &#x005B;<xsl:value-of select="$TARGET_TAPE"/>&#x005D;, import it into library, register it in Storage Manager and import files</xsl:variable>
      <param name="title"><xsl:value-of select="gs:getValue($TITLE,$TITLE_DEFAULT)"/></param>

      <xsl:if test="$hold='yes'">
        <xsl:choose>
          <xsl:when test="$STARTTIME!=''">
            <param name="scheduled_start"><xsl:value-of select="$STARTTIME"/></param>
          </xsl:when>
          <xsl:otherwise>
            <param name="batch_start"><xsl:value-of select="$BATCH_START"/></param>
            <param name="batch_end"><xsl:value-of select="$BATCH_END"/></param>
          </xsl:otherwise>
        </xsl:choose>
        <param name="test_date"><xsl:value-of select="current-date()"/></param>
      </xsl:if>

      <step agent="ltfs_tape_admin" id="verify">
        <param name="title">LTFS Tape Admin: Verify tape [<xsl:value-of select="$TARGET_TAPE"/>] for LTFS compliance and import it into library</param>
        <param name="subfunction">volume_check</param>
        <param name="target_tape"><xsl:value-of select="$TARGET_TAPE"/></param>
        <param name="tape_type"><xsl:value-of select="$TAPE_TYPE"/></param>
        <param name="add_to_pool"><xsl:value-of select="$ADD_TO_POOL"/></param>
        <param name="import_content">yes</param>
        <param name="org_unit"><xsl:value-of select="$ORGUNIT"/></param>
      </step>
    </job>
  </xsl:template>
</xsl:stylesheet>