<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
<mapping>
  <template name="/home/dmae/manager/etc/templates-ev/Sample_MxfPartialRetrieve.xsl"
            label="Sample MXF Partial Retrieve" user="dmae">
    <templateinfo>SAMPLE: Partial retrieve of a MXF file.</templateinfo>
    <dir name="*"/>
    <subsystem name="*"/>
    <filetype name="*" format="*" />
  </template>
  <param>
    <group label="Job parameters">
      <select name="PRIORITY" label="Priority"  type="text" size="1">
        Select the priority at which the job should be executed.
        <option label="LOW"      value="LOW"></option>
        <option label="MEDIUM"   value="MEDIUM"></option>
        <option label="HIGH"     value="HIGH"></option>
        <option label="CRITICAL" value="CRITICAL"></option>
      </select>
    </group>
    <group label="Source and target file names">
      <input name="SOURCE_FILENAME" type="text" size="50" label="Source file name" value="${essence}">
        The name of the source file to process.
      </input>
      <input name="TARGET_FILENAME" type="text" size="50" label="Target file name" value="">
        The name of the target MXF file.
      </input>
      <input name="TIMECODE_IN" type="text" size="10" label="Timecode to begin restore" value="${essence.metadata.som_pretty}">
        The timecode to start partial restore.
      </input>    
      <input name="TIMECODE_OUT" type="text" size="10" label="Timecode to end restore" value="${essence.metadata.eom_pretty}">
        The timecode to end partial restore.
      </input>
      <input name="NEW_TIMECODE_IN" type="text" size="10" label="New timecode of first frame" value="${essence.metadata.som_pretty}">
        The new timecode of the first frame.
      </input>
      <input name="INDEX_FILENAME" type="text" size="50" label="Index filename" value="">
        The name of the index file to speed up processing for certain file types.
      </input> 
      <input name="FRAME_RATE" type="text" size="10" label="Frame rate of file" value="25">
        The frame rate of the file.
      </input>
      <input name="DROP_FRAME" type="checkbox" label="Drop frame" value="yes">
        Check this box to drop frame.
      </input>
      <input name="BLOCK_SIZE" type="text" size="10"  label="Block size (bytes)" value="">
        Block size to use at restore.
      </input>
      <input name="ORGUNIT_IN" type="text" size="10" label="Organization unit" value="">
        Optional: The Organization Unit for the source file.
      </input>
    </group>
  </param>
</mapping>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
                 xmlns:gs="global_settings.xsl">
  <xsl:import href="global_settings.xsl"/>
  <xsl:output method="xml" indent="yes"/>
  <xsl:template match="properties">
    <xsl:param name="PRIORITY" select="param[@name='PRIORITY']"/>
    <xsl:param name="SOURCE_FILENAME" select="param[@name='SOURCE_FILENAME']" />
    <xsl:param name="TARGET_FILENAME" select="param[@name='TARGET_FILENAME']" />
    <xsl:param name="TIMECODE_IN" select="param[@name='TIMECODE_IN']" />
    <xsl:param name="TIMECODE_OUT" select="param[@name='TIMECODE_OUT']" />
    <xsl:param name="NEW_TIMECODE_IN" select="param[@name='NEW_TIMECODE_IN']" />
    <xsl:param name="INDEX_FILENAME" select="param[@name='INDEX_FILENAME']" />
    <xsl:param name="FRAME_RATE" select="param[@name='FRAME_RATE']" />
    <xsl:param name="DROP_FRAME" select="param[@name='DROP_FRAME']" />
    <xsl:param name="BLOCK_SIZE" select="param[@name='BLOCK_SIZE']" />
    <xsl:param name="ORGUNIT_IN" select="param[@name='ORGUNIT_IN']" />

    <xsl:variable name="ORGUNIT">
      <xsl:value-of select="gs:getValue($ORGUNIT_IN,$DEFAULT_ORGUNIT)"/>
    </xsl:variable>

    <job id="mxf_partial_retrieve">
      <param name="title">Partial retrieve from MXF [<xsl:value-of select="$SOURCE_FILENAME"/>]</param>
      <param name="priority"><xsl:value-of select="gs:getPriorityValue($PRIORITY)"/></param>

      <step agent="mxf_partial_retrieve" id="partial_retrieve">
        <param name="title">Partial retrieve from MXF [<xsl:value-of select="$SOURCE_FILENAME"/>]</param>
        <param name="subfunction">partial_retrieve</param>
        <param name="source_filename"><xsl:value-of select="$SOURCE_FILENAME"/></param>
        <param name="target_filename"><xsl:value-of select="$TARGET_FILENAME"/></param>
        <param name="index_filename"><xsl:value-of select="$INDEX_FILENAME"/></param>
        <param name="timecode_in"><xsl:value-of select="$TIMECODE_IN"/></param>
        <param name="timecode_out"><xsl:value-of select="$TIMECODE_OUT"/></param>
        <param name="new_timecode_in"><xsl:value-of select="$NEW_TIMECODE_IN"/></param>
        <param name="frame_rate"><xsl:value-of select="$FRAME_RATE"/></param>
        <param name="drop_frame"><xsl:value-of select="$DROP_FRAME"/></param>
        <param name="block_size"><xsl:value-of select="$BLOCK_SIZE"/></param>
        <param name="org_unit"><xsl:value-of select="$ORGUNIT"/></param>
        <param name="hold_in_cache">yes</param>
      </step>
      
      <step agent="metadata" id="metadata">
        <param name="title">Determine metadata of MXF [<xsl:value-of select="$TARGET_FILENAME"/>]</param>
        <param name="filename"><xsl:value-of select="$TARGET_FILENAME"/></param>
        <properties id="prop">
            <param name="ORIGIN"><xsl:value-of select="$SOURCE_FILENAME"/></param>
        </properties>
        <param name="hold_in_cache">yes</param>
        <param name="org_unit"><xsl:value-of select="$ORGUNIT"/></param>
        <param name="predlist">partial_retrieve</param>
      </step>
    </job>
  </xsl:template>
</xsl:stylesheet>
